==> haskell-data-checked-0.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-checked
version: 0.3
id: data-checked-0.3-DH9Fe5dJViyKqAgzSMxGJ6
key: data-checked-0.3-DH9Fe5dJViyKqAgzSMxGJ6
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-checked
synopsis: Type-indexed runtime-checked properties
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Checked Data.Checked.Strict
abi: f95416440cfd183d3bd00d2d4fa4dd90
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/data-checked-0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/data-checked-0.3
hs-libraries: HSdata-checked-0.3-DH9Fe5dJViyKqAgzSMxGJ6
depends:
    base-4.10.0.0 deepseq-1.4.3.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
haddock-interfaces: /usr/share/doc/haskell-data-checked/html/data-checked.haddock
haddock-html: /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-checked-0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-checked
version: 0.3
id: data-checked-0.3-L4Cm7K1xY6VJQqk5HxNEY
key: data-checked-0.3-L4Cm7K1xY6VJQqk5HxNEY
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-checked
synopsis: Type-indexed runtime-checked properties
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Checked Data.Checked.Strict
abi: 982990a7eef11c3fefa8a28c99e71f31
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-checked-0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-checked-0.3
hs-libraries: HSdata-checked-0.3-L4Cm7K1xY6VJQqk5HxNEY
depends:
    base-4.10.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-data-checked/html/data-checked.haddock
haddock-html: /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
